@@ -123,8 +123,9 @@ class Graph(object):
     >>> G.node[1]
     {'time': '5pm'}
     >>> G.node[1]['room'] = 714
+    >>> del G.node[1]['room'] # remove attribute
     >>> G.nodes(data=True)
-    [(1, {'room': 714, 'time': '5pm'}), (3, {'time': '2pm'})]
+    [(1, {'time': '5pm'}), (3, {'time': '2pm'})]
 
     Warning: adding a node to G.node does not add it to the graph.
 
@@ -254,7 +255,7 @@ class Graph(object):
         >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
         >>> G.add_path([0,1,2,3])
         """
-        return iter(self.adj.keys())
+        return iter(self.node)
 
     def __contains__(self,n):
         """Return True if n is a node, False otherwise. Use the expression
@@ -268,7 +269,7 @@ class Graph(object):
         True
         """
         try:
-            return n in self.adj
+            return n in self.node
         except TypeError:
             return False
 
@@ -288,7 +289,7 @@ class Graph(object):
         4
 
         """
-        return len(self.adj)
+        return len(self.node)
 
     def __getitem__(self, n):
         """Return a dict of neighbors of node n.  Use the expression 'G[n]'.
@@ -372,7 +373,7 @@ class Graph(object):
             except AttributeError:
                 raise NetworkXError(\
                     "The attr_dict argument must be a dictionary.")
-        if n not in self.adj:
+        if n not in self.node:
             self.adj[n] = {}
             self.node[n] = attr_dict
         else: # update attr even if node already exists
@@ -426,10 +427,10 @@ class Graph(object):
         """
         for n in nodes:
             try:
-                newnode=n not in self.adj
+                newnode=n not in self.node
             except TypeError:
                 nn,ndict = n
-                if nn not in self.adj:
+                if nn not in self.node:
                     self.adj[nn] = {}
                     newdict = attr.copy()
                     newdict.update(ndict)
@@ -557,7 +558,7 @@ class Graph(object):
         """
         if data:
             return iter(self.node.items())
-        return iter(self.adj.keys())
+        return iter(self.node)
 
     def nodes(self, data=False):
         """Return a list of the nodes in the graph.
@@ -605,7 +606,7 @@ class Graph(object):
         >>> len(G)
         3
         """
-        return len(self.adj)
+        return len(self.node)
 
     def order(self):
         """Return the number of nodes in the graph.
@@ -620,7 +621,7 @@ class Graph(object):
         number_of_nodes, __len__  which are identical
 
         """
-        return len(self.adj)
+        return len(self.node)
 
     def has_node(self, n):
         """Return True if the graph contains the node n.
@@ -643,7 +644,7 @@ class Graph(object):
 
         """
         try:
-            return n in self.adj
+            return n in self.node
         except TypeError:
             return False
 
@@ -676,9 +677,9 @@ class Graph(object):
         -----
         Adding an edge that already exists updates the edge data.
 
-        NetworkX algorithms designed for weighted graphs use as
-        the edge weight a numerical value assigned to the keyword
-        'weight'.
+        Many NetworkX algorithms designed for weighted graphs use as
+        the edge weight a numerical value assigned to a keyword
+        which by default is 'weight'.
 
         Examples
         --------
@@ -705,10 +706,10 @@ class Graph(object):
                 raise NetworkXError(\
                     "The attr_dict argument must be a dictionary.")
         # add nodes
-        if u not in self.adj:
+        if u not in self.node:
             self.adj[u] = {}
             self.node[u] = {}
-        if v not in self.adj:
+        if v not in self.node:
             self.adj[v] = {}
             self.node[v] = {}
         # add the edge
@@ -778,10 +779,10 @@ class Graph(object):
             else:
                 raise NetworkXError(\
                     "Edge tuple %s must be a 2-tuple or 3-tuple."%(e,))
-            if u not in self.adj:
+            if u not in self.node:
                 self.adj[u] = {}
                 self.node[u] = {}
-            if v not in self.adj:
+            if v not in self.node:
                 self.adj[v] = {}
                 self.node[v] = {}
             datadict=self.adj[u].get(v,{})
@@ -791,7 +792,7 @@ class Graph(object):
             self.adj[v][u] = datadict
 
 
-    def add_weighted_edges_from(self, ebunch, **attr):
+    def add_weighted_edges_from(self, ebunch, weight='weight', **attr):
         """Add all the edges in ebunch as weighted edges with specified
         weights.
 
@@ -801,6 +802,8 @@ class Graph(object):
             Each edge given in the list or container will be added
             to the graph. The edges must be given as 3-tuples (u,v,w)
             where w is a number.
+        weight : string, optional (default= 'weight')
+            The attribute name for the edge weights to be added.
         attr : keyword arguments, optional (default= no attributes)
             Edge attributes to add/update for all edges.
 
@@ -811,15 +814,16 @@ class Graph(object):
 
         Notes
         -----
-        Adding the same edge twice has no effect but any edge data
-        will be updated when each duplicate edge is added.
+        Adding the same edge twice for Graph/DiGraph simply updates 
+        the edge data.  For MultiGraph/MultiDiGraph, duplicate edges 
+        are stored.
 
         Examples
         --------
         >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
         >>> G.add_weighted_edges_from([(0,1,3.0),(1,2,7.5)])
         """
-        self.add_edges_from(((u,v,{'weight':d}) for u,v,d in ebunch),**attr)
+        self.add_edges_from(((u,v,{weight:d}) for u,v,d in ebunch),**attr)
 
     def remove_edge(self, u, v):
         """Remove the edge between u and v.
@@ -884,12 +888,13 @@ class Graph(object):
         >>> ebunch=[(1,2),(2,3)]
         >>> G.remove_edges_from(ebunch)
         """
+        adj=self.adj
         for e in ebunch:
             u,v = e[:2]  # ignore edge data if present
-            if u in self.adj and v in self.adj[u]:
-                del self.adj[u][v]
+            if u in adj and v in adj[u]:
+                del adj[u][v]
                 if u != v:  # self loop needs only one entry removed
-                    del self.adj[v][u]
+                    del adj[v][u]
 
 
     def has_edge(self, u, v):
@@ -972,7 +977,7 @@ class Graph(object):
 
         """
         try:
-            return list(self.adj[n].keys())
+            return list(self.adj[n])
         except KeyError:
             raise NetworkXError("The node %s is not in the graph."%(n,))
 
@@ -995,7 +1000,7 @@ class Graph(object):
         [1]
         """
         try:
-            return iter(self.adj[n].keys())
+            return iter(self.adj[n])
         except KeyError:
             raise NetworkXError("The node %s is not in the graph."%(n,))
 
@@ -1026,6 +1031,7 @@ class Graph(object):
         Notes
         -----
         Nodes in nbunch that are not in the graph will be (quietly) ignored.
+        For directed graphs this returns the out-edges.
 
         Examples
         --------
@@ -1069,6 +1075,7 @@ class Graph(object):
         Notes
         -----
         Nodes in nbunch that are not in the graph will be (quietly) ignored.
+        For directed graphs this returns the out-edges.
 
         Examples
         --------
@@ -1086,7 +1093,7 @@ class Graph(object):
         """
         seen={}     # helper dict to keep track of multiply stored edges
         if nbunch is None:
-            nodes_nbrs = iter(self.adj.items())
+            nodes_nbrs = self.adj.items()
         else:
             nodes_nbrs=((n,self.adj[n]) for n in self.nbunch_iter(nbunch))
         if data:
@@ -1204,7 +1211,7 @@ class Graph(object):
         """
         return iter(self.adj.items())
 
-    def degree(self, nbunch=None, weighted=False):
+    def degree(self, nbunch=None, weight=None):
         """Return the degree of a node or nodes.
 
         The node degree is the number of edges adjacent to that node.
@@ -1214,8 +1221,11 @@ class Graph(object):
         nbunch : iterable container, optional (default=all nodes)
             A container of nodes.  The container will be iterated
             through once.
-        weighted : bool, optional (default=False)
-           If True return the sum of edge weights adjacent to the node.
+
+        weight : string or None, optional (default=None)
+           The edge attribute that holds the numerical value used 
+           as a weight.  If None, then each edge has weight 1.
+           The degree is the sum of the edge weights adjacent to the node.
 
         Returns
         -------
@@ -1236,11 +1246,11 @@ class Graph(object):
 
         """
         if nbunch in self:      # return a single node
-            return next(self.degree_iter(nbunch,weighted=weighted))[1]
+            return next(self.degree_iter(nbunch,weight))[1]
         else:           # return a dict
-            return dict(self.degree_iter(nbunch,weighted=weighted))
+            return dict(self.degree_iter(nbunch,weight))
 
-    def degree_iter(self, nbunch=None, weighted=False):
+    def degree_iter(self, nbunch=None, weight=None):
         """Return an iterator for (node, degree).
 
         The node degree is the number of edges adjacent to the node.
@@ -1250,8 +1260,11 @@ class Graph(object):
         nbunch : iterable container, optional (default=all nodes)
             A container of nodes.  The container will be iterated
             through once.
-        weighted : bool, optional (default=False)
-           If True return the sum of edge weights adjacent to the node.
+
+        weight : string or None, optional (default=None)
+           The edge attribute that holds the numerical value used 
+           as a weight.  If None, then each edge has weight 1.
+           The degree is the sum of the edge weights adjacent to the node.
 
         Returns
         -------
@@ -1273,18 +1286,18 @@ class Graph(object):
 
         """
         if nbunch is None:
-            nodes_nbrs = iter(self.adj.items())
+            nodes_nbrs = self.adj.items()
         else:
             nodes_nbrs=((n,self.adj[n]) for n in self.nbunch_iter(nbunch))
   
-        if weighted:                        
-        # edge weighted graph - degree is sum of nbr edge weights
-            for n,nbrs in nodes_nbrs:
-                yield (n, sum((nbrs[nbr].get('weight',1) for nbr in nbrs)) +
-                              (n in nbrs and nbrs[n].get('weight',1)))
-        else:
+        if weight is None:
             for n,nbrs in nodes_nbrs:
                 yield (n,len(nbrs)+(n in nbrs)) # return tuple (n,degree)
+        else:
+        # edge weighted graph - degree is sum of nbr edge weights
+            for n,nbrs in nodes_nbrs:
+                yield (n, sum((nbrs[nbr].get(weight,1) for nbr in nbrs)) +
+                              (n in nbrs and nbrs[n].get(weight,1)))
 
 
     def clear(self):
@@ -1471,11 +1484,14 @@ class Graph(object):
         bunch =self.nbunch_iter(nbunch)
         # create new graph and copy subgraph into it
         H = self.__class__()
+        # copy node and attribute dictionaries
+        for n in bunch:
+            H.node[n]=self.node[n]
         # namespace shortcuts for speed
         H_adj=H.adj
         self_adj=self.adj
         # add nodes and edges (undirected method)
-        for n in bunch:
+        for n in H.node:
             Hnbrs={}
             H_adj[n]=Hnbrs
             for nbr,d in self_adj[n].items():
@@ -1483,9 +1499,6 @@ class Graph(object):
                     # add both representations of edge: n-nbr and nbr-n
                     Hnbrs[nbr]=d
                     H_adj[nbr][n]=d
-        # copy node and attribute dictionaries
-        for n in H:
-            H.node[n]=self.node[n]
         H.graph=self.graph
         return H
 
@@ -1533,7 +1546,7 @@ class Graph(object):
 
         See Also
         --------
-        selfloop_nodes, number_of_selfloops
+        nodes_with_selfloops, number_of_selfloops
 
         Examples
         --------
@@ -1565,7 +1578,7 @@ class Graph(object):
 
         See Also
         --------
-        selfloop_nodes, selfloop_edges
+        nodes_with_selfloops, selfloop_edges
 
         Examples
         --------
@@ -1578,18 +1591,19 @@ class Graph(object):
         return len(self.selfloop_edges())
 
 
-    def size(self, weighted=False):
+    def size(self, weight=None):
         """Return the number of edges.
 
         Parameters
         ----------
-        weighted : boolean, optional (default=False)
-           If True return the sum of the edge weights.
+        weight : string or None, optional (default=None)
+           The edge attribute that holds the numerical value used 
+           as a weight.  If None, then each edge has weight 1.
 
         Returns
         -------
         nedges : int
-            The number of edges in the graph.
+            The number of edges of sum of edge weights in the graph.
 
         See Also
         --------
@@ -1607,14 +1621,14 @@ class Graph(object):
         >>> G.add_edge('b','c',weight=4)
         >>> G.size()
         2
-        >>> G.size(weighted=True)
+        >>> G.size(weight='weight')
         6.0
         """
-        s=sum(self.degree(weighted=weighted).values())/2
-        if weighted:
-            return float(s)
-        else:
+        s=sum(self.degree(weight=weight).values())/2
+        if weight is None:
             return int(s)
+        else:
+            return float(s)
 
     def number_of_edges(self, u=None, v=None):
         """Return the number of edges between two nodes.
@@ -1706,7 +1720,7 @@ class Graph(object):
 
         """
         nlist = list(nodes)
-        edges=list(zip(nlist[:-1],nlist[1:]))
+        edges=zip(nlist[:-1],nlist[1:])
         self.add_edges_from(edges, **attr)
 
     def add_cycle(self, nodes, **attr):
@@ -1732,7 +1746,7 @@ class Graph(object):
 
         """
         nlist = list(nodes)
-        edges=list(zip(nlist,nlist[1:]+[nlist[0]]))
+        edges=zip(nlist,nlist[1:]+[nlist[0]])
         self.add_edges_from(edges, **attr)
 
 
@@ -1789,7 +1803,8 @@ class Graph(object):
                             yield n
                 except TypeError as e:
                     message=e.args[0]
-#                    sys.stdout.write(message)
+                    import sys
+                    sys.stdout.write(message)
                     # capture error for non-sequence/iterator nbunch.
                     if 'iter' in message:
                         raise NetworkXError(\
