@@ -240,7 +240,7 @@ class GraphMLWriter(GraphML):
         """
         if element_type not in self.xml_type:
             raise nx.NetworkXError('GraphML writer does not support '
-                                   'dict types as data values.')
+                                   '%s as data values.'%element_type)
         key_id = self.get_key(name, self.xml_type[element_type], scope, default)
         data_element = Element("data", key=key_id)
         data_element.text = make_str(value)
@@ -364,14 +364,16 @@ class GraphMLReader(GraphML):
         else:
             G=nx.MultiGraph()
         # set defaults for graph attributes
+        G.graph['node_default']={}
+        G.graph['edge_default']={}
         for key_id,value in defaults.items():
             key_for=graphml_keys[key_id]['for']
             name=graphml_keys[key_id]['name']
             python_type=graphml_keys[key_id]['type']
             if key_for=='node':
-                G.graph['node_default']={name:python_type(value)}
+                G.graph['node_default'].update({name:python_type(value)})
             if key_for=='edge':
-                G.graph['edge_default']={name:python_type(value)}
+                G.graph['edge_default'].update({name:python_type(value)})
         # hyperedges are not supported
         hyperedge=graph_xml.find("{%s}hyperedge" % self.NS_GRAPHML)        
         if hyperedge is not None:
@@ -463,6 +465,11 @@ class GraphMLReader(GraphML):
                 # Assume yfiles as subelements, try to extract node_label
                 node_label = None
                 for node_type in ['ShapeNode', 'SVGNode', 'ImageNode']:
+                    geometry = data_element.find("{%s}%s/{%s}Geometry" % 
+                                (self.NS_Y, node_type, self.NS_Y))
+                    if geometry is not None:
+                        data['x'] = geometry.get('x')
+                        data['y'] = geometry.get('y')
                     if node_label is None:
                         node_label = data_element.find("{%s}%s/{%s}NodeLabel" % 
                                 (self.NS_Y, node_type, self.NS_Y))
