@@ -9,20 +9,18 @@ those with self loops and parallel edges.
 
 Format
 ------
-
 See http://vlado.fmf.uni-lj.si/pub/networks/pajek/doc/draweps.htm
 for format information.
 """
-__author__ = """Aric Hagberg (hagberg@lanl.gov)"""
-#    Copyright (C) 2008-2010 by 
+#    Copyright (C) 2008-2011 by 
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
 #    All rights reserved.
 #    BSD license.
 import networkx as nx
-from networkx.utils import is_string_like,_get_fh,make_str
-
+from networkx.utils import is_string_like, open_file, make_str
+__author__ = """Aric Hagberg (hagberg@lanl.gov)"""
 __all__ = ['read_pajek', 'parse_pajek', 'generate_pajek', 'write_pajek']
 
 def generate_pajek(G):
@@ -56,13 +54,9 @@ def generate_pajek(G):
         id=int(na.get('id',nodenumber[n]))
         nodenumber[n]=id
         shape=na.get('shape','ellipse')
-        s=' '.join(map(make_str,(id,n,x,y,shape)))
+        s=' '.join(map(make_qstr,(id,n,x,y,shape)))
         for k,v in na.items():
-            if is_string_like(v):
-                # add quotes to any values with a blank space
-                if " " in v: 
-                    v="\"%s\""%v
-            s+=' %s %s'%(k,v)
+            s+=' %s %s'%(make_qstr(k),make_qstr(v))
         yield s
 
     # write edges with attributes         
@@ -73,15 +67,13 @@ def generate_pajek(G):
     for u,v,edgedata in G.edges(data=True):
         d=edgedata.copy()
         value=d.pop('weight',1.0) # use 1 as default edge value
-        s=' '.join(map(make_str,(nodenumber[u],nodenumber[v],value)))
+        s=' '.join(map(make_qstr,(nodenumber[u],nodenumber[v],value)))
         for k,v in d.items():
-            if is_string_like(v):
-                # add quotes to any values with a blank space
-                if " " in v: 
-                    v="\"%s\""%v
+            s+=' %s %s'%(make_qstr(k),make_qstr(v))
             s+=' %s %s'%(k,v)
         yield s
-        
+
+@open_file(1,mode='wb')
 def write_pajek(G, path, encoding='UTF-8'):
     """Write graph in Pajek format to path.
 
@@ -103,11 +95,11 @@ def write_pajek(G, path, encoding='UTF-8'):
     See http://vlado.fmf.uni-lj.si/pub/networks/pajek/doc/draweps.htm
     for format information.
     """
-    fh=_get_fh(path, 'wb')
     for line in generate_pajek(G):
         line+='\n'
-        fh.write(line.encode(encoding))
+        path.write(line.encode(encoding))
 
+@open_file(0,mode='rb')
 def read_pajek(path,encoding='UTF-8'):
     """Read graph in Pajek format from path. 
 
@@ -136,8 +128,7 @@ def read_pajek(path,encoding='UTF-8'):
     See http://vlado.fmf.uni-lj.si/pub/networks/pajek/doc/draweps.htm
     for format information.
     """
-    fh=_get_fh(path, 'rb')
-    lines = (line.decode(encoding) for line in fh)
+    lines = (line.decode(encoding) for line in path)
     return parse_pajek(lines)
 
 def parse_pajek(lines):
@@ -220,6 +211,18 @@ def parse_pajek(lines):
     return G
 
 
+
+def make_qstr(t):
+    """Return the string representation of t. 
+    Add outer double-quotes if the string has a space.
+    """
+    if not is_string_like(t): 
+        t = str(t)
+    if " " in t: 
+        t=r'"%s"'%t
+    return t
+
+
 # fixture for nose tests
 def teardown_module(module):
     import os
